<?php

namespace App\Http\Controllers\Password;

use App\Http\Controllers\Controller;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Facades\Validator;
use Carbon\Carbon;
use App\Models\User;
use Illuminate\Support\Facades\Hash;
use Illuminate\Support\Str;
use Illuminate\Support\Facades\Redirect;

class ForgotPasswordController extends Controller
{
    public function showForgotPasswordForm()
    {
        return view('login.forgot_pass');
    }

    public function submitForgotPasswordForm(Request $request)
    {
        $request->validate([
            'email' => 'required|email|exists:users',
        ]);
        $token = Str::random(64);
        DB::table('password_resets')->insert([
            'email' => $request->email,
            'token' => $token,
            'created_at' => Carbon::now()
        ]);
        $check = (new \App\Classes\MailClass)->ForgotPassword($request->email, $token);
        if ($check == 'Error') {
            return back()->with('failed', 'Unable to send email please try later!');
        }
        return back()->with('success', 'We have e-mailed your password reset link!');
    }

    public function showResetPasswordForm($token)
    {

        return view('login.resetPassword', ['token' => $token]);
    }
    public function submitResetPasswordForm(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'email' => 'required|email|exists:users',
                'password' => 'required|string|regex:/^.*(?=.{3,})(?=.*[a-zA-Z])(?=.*[0-9])(?=.*[\d\x])(?=.*[-:~^_@!$#%\[\]]).*$/|between:8,15',
                'password_confirmation' => 'required|same:password'
            ],
            [
                'required' => ':attribute is required.',
                'unique' => ':attribute already exists.',
                'exists' => ':attribute is invalid.',
                'regex' => ':attribute is invalid.',
                'between' => ':attribute must be between :min to :max.',
            ],
            ['name' => 'Name', 'email' => 'Email', 'mobile' => 'Mobile', 'referrer' => 'Referrer', 'password' => 'Password', 'confirm_password' => 'Confirm Password']
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        $updatePassword = DB::table('password_resets')
            ->where([
                'email' => $request->email,
                'token' => $request->token
            ])
            ->first();
        if (!$updatePassword) {
            return back()->withInput()->with('failed', 'Invalid token!');
        }
        User::where('email', $request->email)
            ->update(['password' => Hash::make($request->password)]);

        DB::table('password_resets')->where(['email' => $request->email])->delete();
        return redirect('/')->with('success', 'Your password has been changed!');
    }
}
