<?php

namespace App\Http\Controllers;

use Illuminate\Http\Request;
use App\Models\User;
use App\MsgApp;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
use Illuminate\Support\Facades\Hash;
use App\Rules\MatchOldPassword;

class ProfileController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index()
    {
        $user = auth()->user();
        $readonly = 'readonly';
        return view('profile.index', compact('user', 'readonly'));
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        $user = auth()->user();
        $readonly = null;
        return view('profile.index', compact('user', 'readonly'));
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'name' => MsgApp::REQ,
                'email' => MsgApp::REQ,
                'mobile' => MsgApp::REQ,
                'address' => MsgApp::REQ,
            ],
            [
                'required' => ':attribute is required.',
            ],
            [
                'name' => 'Name',
                'email' => 'Email',
                'mobile' => 'Phone',
                'address' => 'Address',
            ]
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        $user = auth()->user();
        $logo = (new \App\Http\Controllers\CommonController)->uploadFile($request, 'logo', '/media');
        $favicon = (new \App\Http\Controllers\CommonController)->uploadFile($request, 'favicon', '/media');
        
        User::updateProfile($request, $user->id, $logo, $favicon);
        return redirect()->route('profile.index')->with('success', MsgApp::SUCCESS_ADDED);
    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        return redirect()->route('profile.index');
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        return redirect()->route('profile.index');
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        return redirect()->route('profile.index');
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        return redirect()->route('profile.index');
    }

    /**
     * Password Update 
     */

    public function changePassword(Request $request)
    {
        $request->validate([
            'current_password' => ['required', new MatchOldPassword],
            'new_password' => ['required'],
            'new_confirm_password' => ['same:new_password'],
        ]);
        
        User::find(auth()->user()->id)->update(['password' => Hash::make($request->new_password)]);
        return redirect()->route('profile.index')->with('success', 'Password Update Successfully');
    }
}
