<?php

namespace App\Http\Controllers\Setting;

use App\Http\Controllers\Controller;
use App\Models\State;
use App\MsgApp;
use \Yajra\Datatables\Datatables;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Redirect;
use Illuminate\Support\Facades\Validator;
class StateController extends Controller
{
    /**
     * Display a listing of the resource.
     */
    public function index(Request $request)
    {
        if ($request->ajax()) {
            $data = State::select('*');
            return Datatables::of($data)
                ->addIndexColumn()
                ->addColumn('action', function ($row) {
                    $actionBtn = '<div class="d-flex"><a href="' . route('state.edit', $row->id) . '" class="edit btn btn-success btn-sm mr-2">Edit</a> <a href="' . route('state.destroy', $row->id) . '" data-method="delete" class="delete btn btn-danger btn-sm">Delete</a></div>';
                    return $actionBtn;
                })
                ->rawColumns(['action'])
                ->make(true);
        }
        
        return view('setting.state.index');
    }

    /**
     * Show the form for creating a new resource.
     */
    public function create()
    {
        return view('setting.state.create');
    }

    /**
     * Store a newly created resource in storage.
     */
    public function store(Request $request)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'name' => MsgApp::VAL_NAME,
            ],
            [
                'required' => ':attribute is required.',
                'regex' => ':attribute is invalid.',
            ],
            ['name' => 'Name']
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        State::saveData($request);
        return redirect('/setting/state/create')->with('success', MsgApp::SUCCESS_ADDED);
    }

    /**
     * Display the specified resource.
     */
    public function show($id)
    {
        State::where('id', $id)->delete();
        return redirect('/setting/state')->with('success', MsgApp::SUCCESS_DEL);
    }

    /**
     * Show the form for editing the specified resource.
     */
    public function edit($id)
    {
        $data = State::find($id);
        return view('setting.state.edit', compact('data'));
    }

    /**
     * Update the specified resource in storage.
     */
    public function update(Request $request, $id)
    {
        $validator = Validator::make(
            $request->all(),
            [
                'name' => MsgApp::VAL_NAME,
            ],
            [
                'required' => ':attribute is required.',
                'regex' => ':attribute is invalid.',
            ],
            ['name' => 'Name']
        );
        if ($validator->fails()) {
            return Redirect::back()->withErrors($validator)->withInput($request->all());
        }
        State::saveData($request, $id);
        return redirect('/setting/state')->with('success', MsgApp::SUCCESS_ADDED);
    }

    /**
     * Remove the specified resource from storage.
     */
    public function destroy($id)
    {
        //
    }
}
