<?php

use App\Http\Controllers\AppointmentController;
use App\Http\Controllers\Auth\LoginController;
use App\Http\Controllers\PatientController;
use App\Http\Controllers\ProfileController;
use App\Http\Controllers\Setting\CityController;
use App\Http\Controllers\Setting\StateController;
use App\Http\Controllers\CustomController;
use App\Http\Controllers\Password\ForgotPasswordController;
use App\Http\Controllers\TestController;
use Illuminate\Support\Facades\Route;

Route::get('/clear-cache', function () {
    exec('php artisan cache:clear');
    exec('php artisan config:clear');
    exec('php artisan optimize:clear');
    exec('php artisan route:clear');
    exec('php artisan config:cache');
    exec('php artisan view:clear');
    exec('php artisan optimize -force');
    return 'DONE'; //Return anything
});

Route::get('/', [LoginController::class, 'index'])->name('login');
Route::post('/handle-login', [LoginController::class, 'handleLogin'])->name('handle-login');
Route::get('get-city/{id}', [CustomController::class, 'get_city'])->name('get-city');

Route::get('testForm', [TestController::class, 'testForm'])->name('testForm');
Route::post('testPost', [TestController::class, 'testPost'])->name('testPost');
Route::get('test', [TestController::class, 'index'])->name('test');
Route::get('createHash', [TestController::class, 'createHash'])->name('createHash');

Route::get('forgot-password', [ForgotPasswordController::class, 'showForgotPasswordForm'])->name('password.email');
Route::post('forgot-password', [ForgotPasswordController::class, 'submitForgotPasswordForm'])->name('forget.password.post');
Route::get('reset-password/{token}', [ForgotPasswordController::class, 'showResetPasswordForm'])->name('reset.password.get');
Route::post('reset-password', [ForgotPasswordController::class, 'submitResetPasswordForm'])->name('reset.password.post');

Route::group(['middleware' => 'auth'], function () {
    Route::get('/patient/treatment/{id}', [AppointmentController::class, 'treatment'])->name('patient.treatment');
    Route::resource('/patient', PatientController::class);
    Route::get('/treatment/{id}', [PatientController::class, 'treatment'])->name('treatment');
    Route::get('/schedule/{id}', [PatientController::class, 'schedule'])->name('schedule');
    Route::get('/schedule/add/{pid}/{tid}/{schedule_date}', [PatientController::class, 'scheduleAdd'])->name('schedule.add');
    Route::post('/addSchedule', [PatientController::class, 'addSchedule'])->name('addSchedule');
    Route::get('/delSchedule/{tid}/{id}', [PatientController::class, 'delSchedule'])->name('patient.delSchedule');
    Route::get('/getSchedule/{scheduleDate}', [PatientController::class, 'getSchedule'])->name('patient.getSchedule');


    
    Route::get('/patient/add/{id}', [AppointmentController::class, 'add'])->name('patient.add');
    Route::get('/patient/treatment/edit/{pid}/{id}', [AppointmentController::class, 'edit'])->name('patient.treatment.edit');
    Route::post('/patient/treatment/update/{pid}/{id}', [AppointmentController::class, 'update'])->name('patient.treatment.update');
    Route::post('/patient/addNew/{id}', [AppointmentController::class, 'create'])->name('patient.addNew');
    
    

    Route::get('/appointment', [AppointmentController::class, 'index'])->name('appointment.index');
    Route::get('/stsSchedule/{id}', [AppointmentController::class, 'stsSchedule'])->name('appointment.stsSchedule');
    Route::resource('/profile', ProfileController::class);

    Route::post('change-password', [ProfileController::class, 'changePassword'])->name('changePassword');

    Route::group(['prefix' => 'setting'], function () {
        Route::resource('/state', StateController::class);
        Route::resource('/city', CityController::class);
        Route::get('/logout', [LoginController::class, 'logout'])->name('logout');
    });
});
